import type { Metadata } from "next";
import { Inter } from "next/font/google";
import "./globals.css";
import Navbar from "@/components/layout/Navbar";

const inter = Inter({ subsets: ["latin"] });

export const metadata: Metadata = {
  title: "帷幄君臣 - 数字员工平台",
  description: "智能物流解决方案",
};

export default function RootLayout({
  children,
}: {
  children: React.ReactNode;
}) {
  return (
    <html lang="zh">
      <body className={inter.className}>
        <Navbar />
        <main className="min-h-screen bg-gray-50 pt-16">
          {children}
        </main>
        <footer className="bg-[#2F3C7E] text-white py-8">
          <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
            <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
              <div>
                <h3 className="text-lg font-semibold mb-4">关于我们</h3>
                <ul className="space-y-2">
                  <li>公司介绍</li>
                  <li>联系方式</li>
                  <li>加入我们</li>
                </ul>
              </div>
              <div>
                <h3 className="text-lg font-semibold mb-4">产品服务</h3>
                <ul className="space-y-2">
                  <li>数字员工</li>
                  <li>智能客服</li>
                  <li>物流解决方案</li>
                </ul>
              </div>
              <div>
                <h3 className="text-lg font-semibold mb-4">帮助中心</h3>
                <ul className="space-y-2">
                  <li>使用指南</li>
                  <li>常见问题</li>
                  <li>技术支持</li>
                </ul>
              </div>
            </div>
            <div className="mt-8 pt-8 border-t border-gray-700 text-center">
              <p>© 2024 帷幄君臣. All rights reserved.</p>
            </div>
          </div>
        </footer>
      </body>
    </html>
  );
}
